package com.muyu.enterprise.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.muyu.domain.*;
import com.muyu.domain.vo.RuleVo;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * @Author：ChenYan
 * @Project：2112-car-cloud-server
 * @Package：com.muyu.fault.mapper
 * @Filename：RuleMapper
 * @Description TODO
 * @Date：2024/9/21 18:50
 */
@Mapper
public interface RuleMapper extends BaseMapper<Rule> {
    int insertFault(Rule faultInfo);

    int updateFault(Rule faultInfo);


    List<RuleVo> pageQueryRule(RuleVo fault);

    List<Custom> pageQueryList(Custom fault);

    List<Vehicle> pageQueryCar(Vehicle fault);
    List<Type> pageQueryType(Type fault);

    List<MessageValue> pageQueryMessageValue(MessageValue fault);

}
